@@ -1,5 +1,5 @@
 package SimpleDB::Class::Domain;
-our $VERSION = '0.0502';
+our $VERSION = '0.0600';
 
 =head1 NAME
 
@@ -7,7 +7,7 @@ SimpleDB::Class::Domain - A schematic representation of a SimpleDB domain.
 
 =head1 VERSION
 
-version 0.0502
+version 0.0600
 
 =head1 DESCRIPTION
 
@@ -63,6 +63,8 @@ has item_class => (
     },
 );
 
+with 'SimpleDB::Class::Role::Itemized';
+
 #--------------------------------------------------------
 
 =head2 name ( )
@@ -155,8 +157,7 @@ sub find {
         return $e->rethrow;
     }
     elsif (defined $attributes) {
-        return $self->item_class->new(id=>$id, simpledb=>$self->simpledb)
-            ->update($attributes);
+        return $self->instantiate_item($attributes, $id);
     }
     else {
         SimpleDB::Class::Exception->throw(error=>"An undefined error occured while fetching the item.");
@@ -181,13 +182,7 @@ Optionally specify a unqiue id for this item.
 
 sub insert {
     my ($self, $attributes, $id) = @_;
-    my %params = (simpledb=>$self->simpledb);
-    if (defined $id && $id ne '') {
-        $params{id} = $id;
-    }
-    return $self->item_class->new(\%params)
-        ->update($attributes)
-        ->put;
+    return $self->instantiate_item($attributes, $id)->put;
 }
 
 #--------------------------------------------------------
